#
# spec file for package python-crochet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-crochet
Version:        2.1.1
Release:        1.2
Summary:        Use Twisted from any applications
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/itamarst/crochet
Source:         https://files.pythonhosted.org/packages/source/c/crochet/crochet-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Twisted >= 16.0
Requires:       python-wrapt
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Twisted >= 16.0}
BuildRequires:  %{python_module wrapt}
# /SECTION
%python_subpackages

%description
Crochet is an MIT-licensed library that makes it easier for blocking or
threaded applications like Flask or Django to use the Twisted networking
framework.

%prep
%setup -q -n crochet-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest

%files %{python_files}
%doc README.rst docs/*.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * It's possible to decorate ``async/await`` Twisted functions
    with ``@wait_for`` and ``@run_in_reactor``
  * Added type hints, thanks to Merlin Davis.
  * Added formal support for Python 3.9.
  * Dropped the deprecated APIs ``@wait_for_reactor``,
    ``@in_reactor``, ``DeferredResult``, the ``wrapped_function``
    attribute, and unlimited timeouts on ``EventualResult.wait()``.
  * Dropped support for Python 2.7 and 3.5.
* Mon May 10 2021 John Vandenberg <jayvdb@gmail.com>
- Add docs/*.rst to %%doc
- Update to v2.0.0
  * It's possible to decorate async/await Twisted functions with
    @wait_for and @run_in_reactor
  * Added type hints
  * Added formal support for Python 3.9
  * Dropped the deprecated APIs @wait_for_reactor, @in_reactor,
    DeferredResult, the wrapped_function attribute, and
    unlimited timeouts on EventualResult.wait()
  * Dropped support for Python 2.7 and 3.5
* Thu Nov 26 2020 John Vandenberg <jayvdb@gmail.com>
- Remove no longer necessary bcond_with test
- Update to v1.12.0
  * Fix a timeout overflow bug in 32-bit machines
* Fri Dec 27 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.11.0
* Thu Apr 14 2016 termim@gmail.com
- Update to 1.5.0
  * New features:
  - Added support for Python 3.5.
  * Removed features:
  - Python 2.6, Python 3.3, and versions of Twisted < 15.0 are no longer
    supported.
- Update to 1.4.0
  * New features:
  - Added support for Python 3.4.
  * Documentation:
  - Added a section on known issues and workarounds.
  * Bug fixes:
  - Main thread detection (used to determine when Crochet should
    shutdown) is now less fragile. This means Crochet now supports more
    environments, e.g. uWSGI. Thanks to Ben Picolo for the patch.
* Sun Jun  1 2014 termim@gmail.com
- Update to 1.3.0
  * Bug fixes:
  - It is now possible to call ``EventualResult.wait()`` (or functions
    wrapped in ``wait_for``) at import time if another thread holds the
    import lock. Thanks to Ken Struys for the patch.
- Update to 1.2.0
  * New features:
  - ``crochet.wait_for`` implements the timeout/cancellation pattern documented
    in previous versions of Crochet. ``crochet.wait_for_reactor`` and
    ``EventualResult.wait(timeout=None)`` are now deprecated, since lacking
    timeouts they could potentially block forever.
  - Functions wrapped with ``wait_for`` and ``run_in_reactor`` can now be accessed
    via the ``wrapped_function`` attribute, to ease unit testing of the underlying
    Twisted code.
  * API changes:
  - It is no longer possible to call ``EventualResult.wait()`` (or functions
    wrapped with ``wait_for``) at import time, since this can lead to deadlocks
    or prevent other threads from importing. Thanks to Tom Prince for the bug
    report.
  * Bug fixes:
  - ``warnings`` are no longer erroneously turned into Twisted log messages.
  - The reactor is now only imported when ``crochet.setup()`` or
    ``crochet.no_setup()`` are called, allowing daemonization if only ``crochet``
    is imported (http://tm.tl/7105). Thanks to Daniel Nephin for the bug report.
* Sat Mar 15 2014 termim@gmail.com
- Update to 1.1.0
  * Bug fixes:
  - EventualResult.wait() can now be used safely from multiple threads,
    thanks to Gavin Panella for reporting the bug.
  - Fixed reentrancy deadlock in the logging code caused by
    http://bugs.python.org/issue14976, thanks to Rod Morehead for
    reporting the bug.
  - Crochet now installs on Python 3.3 again, thanks to Ben Cordero.
  - Crochet should now work on Windows, thanks to Konstantinos
    Koukopoulos.
  - Crochet tests can now run without adding its absolute path to
    PYTHONPATH or installing it first.
  * Documentation:
  - EventualResult.original_failure is now documented.
* Tue Feb 25 2014 termim@gmail.com
- v.1.0.0 - Initial rpm release
